///File : SplashScreen.cpp
//------------------------------------------------------------------------------
/*
    This file is part of MaxiShoot.

    MaxiShoot is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MaxiShoot is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MaxiShoot.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "SplashScreen.hpp"
//------------------------------------------------------------------------------

SplashScreen::SplashScreen(ConfigObj *configObj) : Screen(configObj)
{

}
//------------------------------------------------------------------------------

int SplashScreen::Run (sf::RenderWindow &App)
{
    // Params
    App.SetView(sf::View(sf::FloatRect(0, 0, 1280, 1024)));
    App.ShowMouseCursor(false);

    // VerticalSync
    #if V_SYNC_IN_MENU
    App.UseVerticalSync(true);
    #else
    App.UseVerticalSync(false);
    #endif

    float totalSplashTime = 0;
    const float fadeTime = 2; // [s]
    const float maxLogoScale = 1.5; // [s]
    bool firstFrame = true;

    // Load the sprite image from a file
    sf::Image Logo;
    if (!Logo.LoadFromFile(m_ConfigObj->GetDataDir() + std::string("/img_c501-logo.png")))
    {
        ERROR_FLUX << "Can't load file \"img_c501-logo.png\" ! Will now exit." << std::endl;
        exit (-1);
    }

    // Create the sprite
    sf::Sprite LogoSpr(Logo);

    sf::SoundBuffer Buffer;
    if (!Buffer.LoadFromFile(m_ConfigObj->GetDataDir() + std::string("/snd_c501-logo-snd.wav")))
    {
        ERROR_FLUX << "Can't load file \"snd_c501-logo-snd.wav\" ! Will now exit." << std::endl;
        exit (-1);
    }

    sf::Sound Sound;
    Sound.SetBuffer(Buffer); // Buffer est un sfSoundBuffer

    Sound.Play();

    // Start game loop
    while (1)
    {
        // Process events
        sf::Event Event;
        while (App.GetEvent(Event))
        {
            // Close window : exit
            if(Event.Type == sf::Event::Closed)
            {
                return -1;
            }

            // Touche 'echap' appuyée
            if(Event.Type == sf::Event::KeyPressed)
            {
                return 4;
            }
        }

        // If fade finish
        if(totalSplashTime >= fadeTime)
        {
            return 4;
        }

        // Get elapsed time
        if(App.GetFrameTime() < 0.1) // Les frames du début sont longues... mais rien n'est encore affiché à l'écran.
        {
            totalSplashTime += App.GetFrameTime();
        }

        float logoAlpha = (totalSplashTime <= fadeTime) ? ((totalSplashTime * 255.f) / fadeTime) : 255;
        LogoSpr.SetColor(sf::Color(255, 255, 255, logoAlpha));

        float logoScale = (totalSplashTime <= fadeTime) ? ((totalSplashTime * maxLogoScale) / fadeTime) : maxLogoScale;
        LogoSpr.SetScale(logoScale, logoScale);

        LogoSpr.SetPosition(1280 / 2 - (Logo.GetWidth() * logoScale) / 2, 1024 / 2 - (Logo.GetHeight() * logoScale) / 2);

        // Clear screen
        App.Clear();

        // Display sprite in our window
        App.Draw(LogoSpr);

        // Display window contents on screen
        App.Display();
    }

    return -1;
}
